=======
History
=======

0.2.0 (2017-07-20)
------------------

* Switched to use the dev version of Python 2.6
* Fixed link target in README
* Fixed typo in README code example
* Added AppRole authentication backend
* Added Transit secret backend
* Created test harness for running Vault in non dev mode
* Added Seal/Unseal, initialization and health methods

0.1.3 (2017-07-17)
------------------

* Fixed rendering of README on PyPI

0.1.2 (2017-07-17)
------------------

* Mostly repository maintenance.
* Updated requirements_dev.txt and setup.py
* Fixed issue where tox was not passing environment variables
* Limited coverage scope to the library not test suite

0.1.1 (2017-07-17)
------------------

* First release on PyPI.
